@@ -1,5 +1,6 @@
 from __future__ import unicode_literals, division, absolute_import
 import argparse
+import contextlib
 from datetime import datetime, timedelta
 from sqlalchemy import func
 
@@ -158,71 +159,70 @@ def display_details(name):
     """Display detailed series information, ie. series show NAME"""
 
     from flexget.manager import Session
-    session = Session()
+    with contextlib.closing(Session()) as session:
 
-    name = normalize_series_name(name)
-    # Sort by length of name, so that partial matches always show shortest matching title
-    matches = (session.query(Series).filter(Series._name_normalized.contains(name)).
-               order_by(func.char_length(Series.name)).all())
-    if not matches:
-        console('ERROR: Unknown series `%s`' % name)
-        return
-    # Pick the best matching series
-    series = matches[0]
-    console('Showing results for `%s`.' % series.name)
-    if len(matches) > 1:
-        console('WARNING: Multiple series match to `%s`.' % name)
-        console('Be more specific to see the results of other matches:')
-        for s in matches[1:]:
-            console(' - %s' % s.name)
+        name = normalize_series_name(name)
+        # Sort by length of name, so that partial matches always show shortest matching title
+        matches = (session.query(Series).filter(Series._name_normalized.contains(name)).
+                   order_by(func.char_length(Series.name)).all())
+        if not matches:
+            console('ERROR: Unknown series `%s`' % name)
+            return
+        # Pick the best matching series
+        series = matches[0]
+        console('Showing results for `%s`.' % series.name)
+        if len(matches) > 1:
+            console('WARNING: Multiple series match to `%s`.' % name)
+            console('Be more specific to see the results of other matches:')
+            for s in matches[1:]:
+                console(' - %s' % s.name)
 
-    console(' %-63s%-15s' % ('Identifier, Title', 'Quality'))
-    console('-' * 79)
+        console(' %-63s%-15s' % ('Identifier, Title', 'Quality'))
+        console('-' * 79)
 
-    # Query episodes in sane order instead of iterating from series.episodes
-    episodes = session.query(Episode).filter(Episode.series_id == series.id)
-    if series.identified_by == 'sequence':
-        episodes = episodes.order_by(Episode.number).all()
-    elif series.identified_by == 'ep':
-        episodes = episodes.order_by(Episode.season, Episode.number).all()
-    else:
-        episodes = episodes.order_by(Episode.identifier).all()
-
-    for episode in episodes:
-
-        if episode.identifier is None:
-            console(' None <--- Broken!')
+        # Query episodes in sane order instead of iterating from series.episodes
+        episodes = session.query(Episode).filter(Episode.series_id == series.id)
+        if series.identified_by == 'sequence':
+            episodes = episodes.order_by(Episode.number).all()
+        elif series.identified_by == 'ep':
+            episodes = episodes.order_by(Episode.season, Episode.number).all()
         else:
-            console(' %s (%s) - %s' % (episode.identifier, episode.identified_by or 'N/A', episode.age))
+            episodes = episodes.order_by(Episode.identifier).all()
 
-        for release in episode.releases:
-            status = release.quality.name
-            title = release.title
-            if len(title) > 55:
-                title = title[:55] + '...'
-            if release.proper_count > 0:
-                status += '-proper'
-                if release.proper_count > 1:
-                    status += str(release.proper_count)
-            if release.downloaded:
-                console('  * %-60s%-15s' % (title, status))
+        for episode in episodes:
+
+            if episode.identifier is None:
+                console(' None <--- Broken!')
             else:
-                console('    %-60s%-15s' % (title, status))
+                console(' %s (%s) - %s' % (episode.identifier, episode.identified_by or 'N/A', episode.age))
 
-    console('-' * 79)
-    console(' * = downloaded')
-    if not series.identified_by:
-        console('')
-        console(' Series plugin is still learning which episode numbering mode is ')
-        console(' correct for this series (identified_by: auto).')
-        console(' Few duplicate downloads can happen with different numbering schemes')
-        console(' during this time.')
-    else:
-        console(' Series uses `%s` mode to identify episode numbering (identified_by).' % series.identified_by)
-    console(' See option `identified_by` for more information.')
-    if series.begin:
-        console(' Begin episode for this series set to `%s`.' % series.begin.identifier)
-    session.close()
+            for release in episode.releases:
+                status = release.quality.name
+                title = release.title
+                if len(title) > 55:
+                    title = title[:55] + '...'
+                if release.proper_count > 0:
+                    status += '-proper'
+                    if release.proper_count > 1:
+                        status += str(release.proper_count)
+                if release.downloaded:
+                    console('  * %-60s%-15s' % (title, status))
+                else:
+                    console('    %-60s%-15s' % (title, status))
+
+        console('-' * 79)
+        console(' * = downloaded')
+        if not series.identified_by:
+            console('')
+            console(' Series plugin is still learning which episode numbering mode is ')
+            console(' correct for this series (identified_by: auto).')
+            console(' Few duplicate downloads can happen with different numbering schemes')
+            console(' during this time.')
+        else:
+            console(' Series uses `%s` mode to identify episode numbering (identified_by).' % series.identified_by)
+        console(' See option `identified_by` for more information.')
+        if series.begin:
+            console(' Begin episode for this series set to `%s`.' % series.begin.identifier)
 
 
 @event('options.register')
