@@ -3,7 +3,6 @@ import logging
 from datetime import datetime, timedelta
 from flexget.utils.simple_persistence import SimplePersistence
 from flexget.event import event
-from flexget import manager
 
 log = logging.getLogger('db_vacuum')
 VACUUM_INTERVAL = timedelta(weeks=24) # 6 months
@@ -17,6 +16,5 @@ def on_cleanup(session):
     last_vacuum = persistence.get('last_vacuum')
     if not last_vacuum or last_vacuum < datetime.now() - VACUUM_INTERVAL:
         log.info('Running VACUUM on database to improve performance and decrease db size.')
-        session = manager.Session()
         session.execute('VACUUM')
         persistence['last_vacuum'] = datetime.now()
