@@ -1,4 +1,4 @@
-from __future__ import unicode_literals, division, absolute_import
+from __future__ import unicode_literals, division, absolute_import, print_function
 import logging
 
 from flexget import options, plugin
@@ -31,10 +31,10 @@ class PluginTryRegexp(object):
         if self.abort:
             return
 
-        print '-' * 79
-        print 'Hi there, welcome to try regexps in realtime!'
-        print 'Press ^D or type \'exit\' to continue. Type \'continue\' to continue non-interactive execution.'
-        print 'Task \'%s\' has %s entries, enter regexp to see what matches it.' % (task.name, len(task.entries))
+        print('-' * 79)
+        print('Hi there, welcome to try regexps in realtime!')
+        print('Press ^D or type \'exit\' to continue. Type \'continue\' to continue non-interactive execution.')
+        print('Task \'%s\' has %s entries, enter regexp to see what matches it.' % (task.name, len(task.entries)))
         while (True):
             try:
                 s = raw_input('--> ')
@@ -51,13 +51,13 @@ class PluginTryRegexp(object):
                 try:
                     match, field = self.matches(entry, s)
                     if match:
-                        print 'Title: %-40s URL: %-30s From: %s' % (entry['title'], entry['url'], field)
+                        print('Title: %-40s URL: %-30s From: %s' % (entry['title'], entry['url'], field))
                         count += 1
                 except:
-                    print 'Invalid regular expression'
+                    print('Invalid regular expression')
                     break
-            print '%s of %s entries matched' % (count, len(task.entries))
-        print 'Bye!'
+            print('%s of %s entries matched' % (count, len(task.entries)))
+        print('Bye!')
 
 
 @event('plugin.register')
