@@ -1,6 +1,8 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
-from flexget.plugin import register_plugin
+
+from flexget import plugin
+from flexget.event import event
 
 log = logging.getLogger("stmusic")
 
@@ -16,4 +18,7 @@ class UrlRewriteSTMusic(object):
         entry['url'] = entry['url'].replace('details.php?id=', 'download.php/')
         entry['url'] += '/%s.torrent' % (urllib.quote(entry['title'], safe=''))
 
-register_plugin(UrlRewriteSTMusic, 'stmusic', groups=['urlrewriter'])
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(UrlRewriteSTMusic, 'stmusic', groups=['urlrewriter'], api_ver=2)
