@@ -35,9 +35,7 @@ def do_inject():
     if fields.get('title') and fields.get('url'):
         # Create the entry for injection
         entry = Entry(**fields)
-        # TODO: Fix
-        for task in manager.tasks:
-            manager.scheduler.execute(task, options={'dump_entries': True, 'inject': [entry]})
+        manager.execute(options={'dump_entries': True, 'inject': [entry]})
         flash('Scheduled execution for entry `%s`' % entry['title'], 'success')
     else:
         flash('Title and URL required for inject.', 'error')
