@@ -1,7 +1,6 @@
 from __future__ import unicode_literals, division, absolute_import
 
 from nose.plugins.attrib import attr
-from nose.plugins.skip import SkipTest
 
 from tests import FlexGetBase
 
@@ -15,7 +14,12 @@ class TestInputSites(FlexGetBase):
           test_sceper:
             sceper: http://sceper.ws/category/movies/movies-dvd-rip
           test_apple_trailers:
-              apple_trailers: 480p
+            apple_trailers:
+              quality: 480p
+              genres: ['Action and Adventure']
+          test_apple_trailers_simple:
+            apple_trailers: 720p
+
     """
 
     @attr(online=True)
@@ -30,6 +34,10 @@ class TestInputSites(FlexGetBase):
 
     @attr(online=True)
     def test_apple_trailers(self):
-        raise SkipTest('apple_trailers plugin is currently broken')
         self.execute_task('test_apple_trailers')
         assert self.task.entries, 'no entries created / site may be down'
+
+    @attr(online=True)
+    def test_apple_trailers_simple(self):
+        self.execute_task('test_apple_trailers_simple')
+        assert self.task.entries, 'no entries created / site may be down'
