@@ -14,7 +14,7 @@ class TestTvRage(FlexGetBase):
     @attr(online=True)
     def test_tvrage(self):
         friends = lookup_series("Friends")
-        assert friends.genres == ['Comedy']
+        assert friends.genres == ['Comedy', 'Romance/Dating']
         s1e22 = friends.find_episode(1, 22)
         log.info("s1e22 %s " % s1e22)
 
